# Installation

The package can be installed from [PyPI](https://pypi.org/project/solposx/) with the following command:

    pip install solposx

Some functions require additional optional dependencies, e.g., the Python packages [skyfield](https://pypi.org/project/skyfield/) and [sg2](https://pypi.org/project/sg2). For convenience, the optional dependencies can be installed with the following command:

    pip install solposx[optional]

The source code is openly developed on [GitHub](https://github.com/pvlib/solposx).
